
const util = require('../../utils/util');
const request = require('../../utils/request');
const api = require('../../utils/api');
const yesterday = new Date(Date.now() - 864e5);
const todayStr = util.formatTime(new Date(Date.now()));
const yesterdayStr = util.formatTime(yesterday);
Page({
    data: {
        date: yesterdayStr,
        currentDate: yesterdayStr,
        planArray: [], // 计划名称数组
        planIndex: 0,
        planData: [], // 计划对象数组
        consumeTotal: '',
        showPvTotal: '',
        clickPvTotal: '',
        clickRateTotal: '',
        chartsData: [],
        chartsDateArray: [],
        currentPlanId: '',
        opts: {
            lazyLoad: true // 延迟加载组件
        },
    },


    onReady() {
        this.queryData();
    },

    dateSelected(e) {
        this.setData({
            date: e.detail.value,
            currentDate: e.detail.value
        })
        this.queryPlanTotal(e.detail.value, this.data.currentPlanId);
        this.queryPlanTrend(e.detail.value, this.data.currentPlanId);
    },
    pickerChange(e){
    //  console.log('picker发送选择改变，携带值为', e.detail.value)
     let index = e.detail.value;
     this.setData({
        planIndex:index,
        currentPlanId:this.data.planData[index].id
     })
     this.queryPlanTotal(this.data.currentDate, this.data.currentPlanId);
     this.queryPlanTrend(this.data.currentDate, this.data.currentPlanId);
    },
    queryData() {
        wx.showLoading({
            title: '加载中',
        })
        var that = this;
        request.Get(api.campaignSimple(), function (res) {
            wx.hideLoading();
            if (res.code == '200') {
                if (res.data.length == 0) {
                    wx.showToast({
                        title: "没有推广计划可查询",
                        icon: 'none',
                        duration: 1500
                    })
                } else {
                    that.setData({
                        planData: res.data,
                        planArray: res.data.map(item => { return item.name }),
                        currentPlanId: res.data[0].id
                    })
                    that.queryPlanTotal(yesterdayStr, that.data.planData[0].id);
                    that.queryPlanTrend(yesterdayStr, that.data.planData[0].id);
                }
            } else {
                wx.showToast({
                    title: res.msg,
                    icon: 'none',
                    duration: 1500
                })
            }
        })
    },

    queryPlanTotal(dateStr, planId) {
        var that = this;
        let data = { 'date': dateStr, 'id': planId };
        request.Get(api.campaignTotal(), data, function (res) {
            // console.log('queryPlanTotal>>>>>>>>>',JSON.stringify(res));
            if (res.code == '200') {
                that.setData({
                    consumeTotal: util.numberWithCommas(String(res.data.consumeTotal)),
                    showPvTotal: util.numberWithCommas(String(res.data.showPvTotal)),
                    clickPvTotal: util.numberWithCommas(String(res.data.clickPvTotal)),
                    clickRateTotal: util.numberWithCommas(String(res.data.clickRateTotal))
                })
            } else {
                wx.showToast({
                    title: res.msg,
                    icon: 'none',
                    duration: 1500
                })
            }
        });
    },

    queryPlanTrend(dateStr, planId) {
        var that = this;
        let data = { 'beginDate': '2019-03-01', 'endDate': dateStr, 'id': planId };
        request.Get(api.campaignTrend(), data, function (res) {
            // console.log("queryPlanTrend>>>>>>>>>>>", JSON.stringify(res));
            if (res.code == '200') {
                var tempData = res.data.map(item => {
                    return { date: item.date, value: item.consume }
                });
                let dateArray = res.data.map(item => {
                    return item.date;
                })
                that.setData({
                    chartsData: tempData,
                    chartsDateArray: dateArray
                })
                that.drawCharts();
            } else {
                wx.showToast({
                    title: res.msg,
                    icon: 'none',
                    duration: 1500
                })
            }
        })
    },
    
    drawCharts() {
        const self = this;
        self.chartComponent = self.selectComponent('#line-dom');
        self.chartComponent.init((canvas, width, height, F2) => {
            // console.log("chartsData>>>>>>>>>>", self.data.chartsData);
            const data = self.data.chartsData;
            let chart = new F2.Chart({
                el: canvas,
                width,
                height
            });
            chart.source(data, {
                date: {
                    range: [0, 1],
                    ticks: self.data.chartsDateArray
                },
                value: {
                    tickCount: 10,
                    formatter(val) {
                        return val;//val.toFixed(1);
                    }
                }
            });
            chart.line().position('date*value').color('type', val => {
                return 'red';
            });
            chart.render();
            return chart;
        });
    },






})